@@ -25,18 +25,15 @@ import click
 
 from molecule.command import base
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Dependency(base.Base):
     """Dependency Command Class."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule dependency` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule dependency` and returns None."""
         self._config.dependency.execute()
 
 
@@ -48,10 +45,10 @@ class Dependency(base.Base):
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
     help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
-def dependency(ctx, scenario_name):  # pragma: no cover
+def dependency(ctx, scenario_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
     """Manage the role's dependencies."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"subcommand": subcommand}
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args)
