@@ -27,6 +27,7 @@ import os
 from molecule import util
 from molecule.dependency import base
 
+
 LOG = logging.getLogger(__name__)
 
 
@@ -37,7 +38,7 @@ class AnsibleGalaxyBase(base.Base):
 
     FILTER_OPTS = ()
 
-    def __init__(self, config) -> None:
+    def __init__(self, config) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Construct AnsibleGalaxy."""
         super().__init__(config)
         self._sh_command = None
@@ -46,11 +47,11 @@ class AnsibleGalaxyBase(base.Base):
 
     @property
     @abc.abstractmethod
-    def requirements_file(self):  # cover
+    def requirements_file(self):  # type: ignore[no-untyped-def] # cover  # noqa: ANN201, D102
         pass
 
     @property
-    def default_options(self):
+    def default_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         d = {
             "force": False,
         }
@@ -59,14 +60,15 @@ class AnsibleGalaxyBase(base.Base):
 
         return d
 
-    def filter_options(self, opts, keys):
+    def filter_options(self, opts, keys):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
         """Filter certain keys from a dictionary.
 
         Removes all the values of ``keys`` from the dictionary ``opts``, if
         they are present. Returns the resulting dictionary. Does not modify the
         existing one.
 
-        :return: A copy of ``opts`` without the value of keys
+        Returns:
+            A copy of ``opts`` without the value of keys
         """
         c = copy.copy(opts)
         for key in keys:
@@ -77,59 +79,52 @@ class AnsibleGalaxyBase(base.Base):
     # NOTE(retr0h): Override the base classes' options() to handle
     # ``ansible-galaxy`` one-off.
     @property
-    def options(self):
+    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         o = self._config.config["dependency"]["options"]
         # NOTE(retr0h): Remove verbose options added by the user while in
         # debug.
         if self._config.debug:
-            o = util.filter_verbose_permutation(o)
+            o = util.filter_verbose_permutation(o)  # type: ignore[no-untyped-call]
 
         o = util.merge_dicts(self.default_options, o)
-        return self.filter_options(o, self.FILTER_OPTS)
+        return self.filter_options(o, self.FILTER_OPTS)  # type: ignore[no-untyped-call]
 
     @property
-    def default_env(self):
+    def default_env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return util.merge_dicts(os.environ, self._config.env)
 
-    def bake(self):
-        """Bake an ``ansible-galaxy`` command so it's ready to execute and returns \
-        None.
-
-        :return: None
-        """
+    def bake(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Bake an ``ansible-galaxy`` command so it's ready to execute and returns None."""
         options = self.options
-        verbose_flag = util.verbose_flag(options)
+        verbose_flag = util.verbose_flag(options)  # type: ignore[no-untyped-call]
 
         self._sh_command = [
             self.command,
-            *self.COMMANDS,
+            *self.COMMANDS,  # type: ignore[attr-defined]  # pylint: disable=no-member
             *util.dict2args(options),
             *verbose_flag,
         ]
 
-    def execute(self, action_args=None):
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002, D102
         if not self.enabled:
             msg = "Skipping, dependency is disabled."
             LOG.warning(msg)
             return
-        super().execute()
+        super().execute()  # type: ignore[no-untyped-call]
 
-        if not self._has_requirements_file():
+        if not self._has_requirements_file():  # type: ignore[no-untyped-call]
             msg = "Skipping, missing the requirements file."
             LOG.warning(msg)
             return
 
         if self._sh_command is None:
-            self.bake()
+            self.bake()  # type: ignore[no-untyped-call]
 
-        self._setup()
-        self.execute_with_retries()
+        self._setup()  # type: ignore[no-untyped-call]
+        self.execute_with_retries()  # type: ignore[no-untyped-call]
 
-    def _setup(self):
-        """Prepare the system for using ``ansible-galaxy`` and returns None.
+    def _setup(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Prepare the system for using ``ansible-galaxy`` and returns None."""
 
-        :return: None
-        """
-
-    def _has_requirements_file(self):
-        return os.path.isfile(self.requirements_file)
+    def _has_requirements_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        return os.path.isfile(self.requirements_file)  # noqa: PTH113
