@@ -30,17 +30,17 @@ class Verifier:
 
     __metaclass__ = abc.ABCMeta
 
-    def __init__(self, config=None) -> None:
+    def __init__(self, config=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Initialize code for all :ref:`Verifier` classes.
 
-        :param config: An instance of a Molecule config.
-        :returns: None
+        Args:
+            config: An instance of a Molecule config.
         """
         self._config = config
 
     @property
     @abc.abstractmethod
-    def name(self):  # pragma: no cover
+    def name(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
         """Name of the verifier and returns a string.
 
         :returns: str
@@ -48,75 +48,71 @@ class Verifier:
 
     @property
     @abc.abstractmethod
-    def default_options(self):  # pragma: no cover
+    def default_options(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
         """Get default CLI arguments provided to ``cmd`` as a dict.
 
-        :return: dict
+        Return:
+            dict
         """
 
     @property
     @abc.abstractmethod
-    def default_env(self):  # pragma: no cover
+    def default_env(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
         """Get default env variables provided to ``cmd`` as a dict.
 
-        :return: dict
+        Return:
+            dict
         """
 
     @abc.abstractmethod
-    def execute(self, action_args=None):  # pragma: no cover
-        """Execute ``cmd`` and returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
+        """Execute ``cmd`` and returns None."""
 
     @abc.abstractmethod
-    def schema(self):  # pragma: no cover
-        """Return validation schema.
-
-        :return: None
-        """
+    def schema(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
+        """Return validation schema."""
 
     @property
-    def enabled(self):
+    def enabled(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["verifier"]["enabled"]
 
     @property
-    def directory(self):
-        return os.path.join(
+    def directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(  # noqa: PTH118
             self._config.scenario.directory,
             self._config.config["verifier"].get("directory", "tests"),
         )
 
     @property
-    def options(self):
+    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return util.merge_dicts(
             self.default_options,
             self._config.config["verifier"]["options"],
         )
 
     @property
-    def env(self):
+    def env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return util.merge_dicts(
             self.default_env,
             self._config.config["verifier"]["env"],
         )
 
-    def __eq__(self, other):
+    def __eq__(self, other):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN204
         """Implement equality comparison."""
         return str(self) == str(other)
 
-    def __lt__(self, other):
+    def __lt__(self, other):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN204
         """Implement lower than comparison."""
         return str.__lt__(str(self), str(other))
 
-    def __hash__(self):
+    def __hash__(self):  # type: ignore[no-untyped-def]  # noqa: ANN204
         """Implement hashing."""
         return self.name.__hash__()
 
     def __str__(self) -> str:
         """Return readable string representation of object."""
-        return self.name
+        return self.name  # type: ignore[no-any-return]
 
     def __repr__(self) -> str:
         """Return detailed string representation of object."""
-        return self.name
+        return self.name  # type: ignore[no-any-return]
